@@ -124,7 +124,7 @@ def artefacts(tmp_path):
                 "CPUPOWER=https://example.com/cpupower.tar.xz",
                 "KSELFTEST=https://example.com/kselftest.tar.xz",
             ],
-            "qemu-armv7-kselftest-ipc.yaml",
+            "qemu-armv7-kselftest-ipc-cpupower.yaml",
         ),
         (
             [
@@ -173,10 +173,26 @@ def artefacts(tmp_path):
             ["--device", "qemu-i386", "--tests", "kunit"],
             "qemu-i386-kunit.yaml",
         ),
+        (
+            ["--device", "qemu-i386", "--tests", "libgpiod"],
+            "qemu-i386-libgpiod.yaml",
+        ),
+        (
+            ["--device", "qemu-i386", "--tests", "libhugetlbfs"],
+            "qemu-i386-libhugetlbfs.yaml",
+        ),
         (
             ["--device", "qemu-i386", "--tests", "perf"],
             "qemu-i386-perf.yaml",
         ),
+        (
+            ["--device", "qemu-i386", "--tests", "rcutorture"],
+            "qemu-i386-rcutorture.yaml",
+        ),
+        (
+            ["--device", "qemu-i386", "--tests", "v4l2"],
+            "qemu-i386-v4l2.yaml",
+        ),
         (
             [
                 "--device",
